# == Define: systemtap::module
#
# Installs a pre-compiled systemtap module.  The title of this resource must
# be the same as the name of the module, as specified at compile time.  If
# unknown, try loading the module and running 'lsmod' to ascertain its name.
#
# === Parameters:
#
# [*filepath*]
#
# Installs the module located at $filepath in the filesystem
#
define systemtap::module ( $filepath = undef ) {
  include systemtap::runtime_package

  if ! $filepath {
    fail("Systemtap::Module[${name}] : You must specify a filepath")
  } elsif ! $filepath =~ /^(\/[a-z0-9_\-\. ]+)+$/ {
    fail("Systemtap::Module[${name}] : Path is not absolute")
  }
  # for some reason, validate_absolute_path seems to not like certain paths
  # i'll need to look into it more.
  #  validate_absolute_path( $filepath,
  #  "Systemtap::Module[${title}] : filepath must be absolute. <${filepath}>" )

  exec { "load-systemtap-module-${name}":
    command => "/usr/bin/staprun -L ${filepath}",
    unless  => "/sbin/lsmod | /bin/egrep '^${name}'",
    require => Class['systemtap::runtime_package'],
  }
}
